%define daemon_user monitor
%if 0%{?suse_version}
%define htmlroot /srv/www/htdocs
%define httpconfdir apache2/conf.d
%define daemon_group www
%define apache_group wwwrun
%else
%define htmlroot /var/www/html
%define httpconfdir httpd/conf.d
%define daemon_group apache
%define apache_group apache
%endif
Summary: Small programs to check the status of various services in a network.
Name: plugins-nagios
Version: %{op5version}
Release: %{op5release}%{?dist}
License: GPLv3 with exceptions
Group: op5/Plugins
URL: http://www.op5.se
Prefix: /opt/plugins
Source0: %name-%version.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}
BuildRequires: mysql-devel, postgresql-devel, openssl-devel, perl, sqlite-devel
BuildRequires: automake, autoconf
BuildRequires: libdbi-devel, bind-utils, perl(Net::SNMP), postfix
BuildRequires: samba-client < 4.0.0
# Don't know what these are, but we apparently don't want 'em?
#BuildRequires: lmstat, qstat, fping, qmail-qstat
Requires: perl
Requires: nrpe-client
Requires: plugins-nagios-local
Requires: perl(Crypt::Rijndael)
Requires: perl(DBD::Sybase)
Requires: samba-client < 4.0.0
Requires: perl(Net::SNMP)
Conflicts: plugins-sensatronics
Provides: plugins = %{version}
Obsoletes: plugins < %{version}
%if 0%{?suse_version}
# SLES-specific stuff
Requires: net-snmp
BuildRequires: freeradius-client-devel
BuildRequires: openldap2-devel
BuildRequires: openssh
BuildRequires: net-snmp
%else
# Common RHEL stuff
Requires: net-snmp-utils
BuildRequires: radiusclient-ng-devel
BuildRequires: openldap-devel
BuildRequires: openssh-clients
BuildRequires: net-snmp-utils
%endif

# /usr/bin/nslookup, for check_dns:
Requires: bind-utils


%description
The plugins collection is a set of small scripts and programs that
can check the status of various things in the network. They are
also useful for harvesting statistics about the services they are
told to check.

Included are plugins to check status of and harvest statistics
from most RFC-compliant networking services, as well as interacting
remotely through various agents and ssh. There is also support for
performing responsetime checks on various databases (MySQL,
PostgreSQL, Sybase and MSSQL), as well as checking temperatures
(requires additional hardware) and various other things.


%package unsupported
Summary: Unsupported plugins contributed by various online users.
Group: op5/Plugins

%description unsupported
The unsupported plugins collection is just that; unsupported. They are
neither tested nor proven reliable. Nevertheless, they might prove useful
and are as such made available.

%package local
Summary: Plugins targeted for remote hosts monitored by op5 Monitor / Nagios
Group: op5/Plugins
Obsoletes: plugins-local

%description local
Plugins targeted for remote hosts monitored by op5 Monitor / Nagios


%package test
Summary: Dummy-package for adding test requirements
Group: op5/plugins
# Requires everything that's used to build, to reproduce configure options
# (stupid copy-paste)
Requires: mysql-devel, postgresql-devel, openssl-devel, perl, sqlite-devel
Requires: automake, autoconf
Requires: libdbi-devel, postfix
%if 0%{?suse_version}
Requires: freeradius-client-devel
Requires: openldap2-devel
Requires: openssh
Requires: net-snmp
%else
Requires: radiusclient-ng-devel
Requires: openldap-devel
Requires: openssh-clients, openssh-server
Requires: net-snmp-utils
%endif
# And test stuffs!
%if 0%{?suse_version}
Requires: libdbi-drivers-dbd-sqlite3
Requires: cron
Requires: dovecot20
Requires: netcat
Requires: mysql
%else
Requires: cronie
Requires: net-snmp-libs
Requires: libdbi-dbd-sqlite
Requires: dovecot
Requires: nc
Requires: mysql-server
Requires: perl-Test-Harness
%endif
Requires: perl-Test-Simple
Requires: sqlite
Requires: libdbi-devel
Requires: net-snmp
Requires: ntp
Requires: xinetd
Requires: httpd

%description test
This package has no plugins, it's just an empty dummy package

%prep
%setup -q


%build
sh tools/setup
%configure \
	--prefix=/opt/monitor \
	--libexecdir=%prefix \
	--disable-nls \
	--disable-rpath \
	--disable-dependency-tracking \
	--with-rpcinfo-command=/usr/sbin/rpcinfo

%__make


%install
rm -rf %buildroot
make DESTDIR=%buildroot install
mkdir -p -m 755 %buildroot%prefix/suid

# install contrib plugins as unsupported
mv contrib %buildroot%prefix/unsupported
install -m 644 README.unsupported-plugins %buildroot%prefix/unsupported/README

cp plugins-root/check_dhcp %buildroot%prefix

pushd %buildroot%prefix
mv check_dhcp suid

# symlink everyting from suid to %prefix
chmod 4755 suid/*
for i in suid/*; do
	test -e ${i##*/} && rm -f ${i##*/}
	ln -s $i .
done

# create the "custom-plugins" directory
mkdir -m 0755 custom

# fix the perl scripts' "use" path
for f in `grep -l ^#.*perl check_* unsupported/check_*`; do
	sed -i $f \
		-e 's|^#!.*perl.*|#!/usr/bin/perl|' \
		-e 's|^[\t ]*use strict.*|# &|' \
		-e 's|^[\t ]*use lib.*|use lib "%prefix";|'
done

# Some customers have check-commands in op5 Monitor that
# actually still use the plugin.{pl,sh} form, so we need
# to maintain it indefinitely. It's no great chore though,
# so humor them.
for f in check_*; do
	file $f | grep -q perl && ln -s $f $f.pl && continue
	file $f | grep -q "shell script" && ln -s $f $f.sh
done
popd

# Add /opt/plugins to $PERLLIB with a profile script
mkdir -p -m 0755 %buildroot%{_sysconfdir}/profile.d
cp op5build/op5plugins.sh %buildroot%{_sysconfdir}/profile.d

# Remove unpackaged files
rm -rf %buildroot/usr

# Remove files conflicting with the op5plugins package
rm %buildroot%prefix/check_oracle*
#rm %buildroot%prefix/check_ifoperstatus*
rm %buildroot%prefix/check_ifstatus*
rm %buildroot%prefix/check_ping

mkdir -p %buildroot%_docdir
cp README.test %buildroot%_docdir


%clean
rm -rf %buildroot


%files
%defattr(755,root,root,755)
%prefix
%attr(4755, root, root) %prefix/suid/*
%exclude %prefix/check_disk
%exclude %prefix/check_load
%exclude %prefix/check_procs
%exclude %prefix/check_swap
%exclude %prefix/check_users
%exclude %prefix/negate
%exclude %prefix/urlize
%exclude %prefix/utils.pm
%exclude %prefix/utils.sh
%exclude %{_sysconfdir}/profile.d/op5plugins.sh

%files local
%defattr(755,root,root,755)
%prefix/check_disk
%prefix/check_load
%prefix/check_procs
%prefix/check_swap
%prefix/check_users
%prefix/negate
%prefix/urlize
%prefix/utils.pm
%prefix/utils.sh
%{_sysconfdir}/profile.d/op5plugins.sh

%files test
%_docdir/README.test

%changelog
* Thu Nov 8 2007 Andreas Ericsson <ae@op5.se>
- Specfile for use with autobuild machinery.
